declare const _default: {
    readonly swagger: "2.0";
    readonly info: {
        readonly version: "1.0.0";
        readonly title: "Swagger Petstore";
        readonly license: {
            readonly name: "MIT";
        };
    };
    readonly host: "petstore.swagger.io";
    readonly basePath: "/v1";
    readonly schemes: readonly ["http"];
    readonly consumes: readonly ["application/json"];
    readonly produces: readonly ["application/json"];
    readonly paths: {
        readonly "/pets": {
            readonly get: {
                readonly summary: "List all pets";
                readonly operationId: "listPets";
                readonly tags: readonly ["pets"];
                readonly parameters: readonly [{
                    readonly name: "limit";
                    readonly in: "query";
                    readonly description: "How many items to return at one time (max 100)";
                    readonly required: false;
                    readonly type: "integer";
                    readonly format: "int32";
                }];
                readonly responses: {
                    readonly "200": {
                        readonly description: "A paged array of pets";
                        readonly headers: {
                            readonly "x-next": {
                                readonly type: "string";
                                readonly description: "A link to the next page of responses";
                            };
                        };
                        readonly schema: {
                            readonly $ref: "#/definitions/Pets";
                        };
                    };
                    readonly default: {
                        readonly description: "unexpected error";
                        readonly schema: {
                            readonly $ref: "#/definitions/Error";
                        };
                    };
                };
            };
            readonly post: {
                readonly summary: "Create a pet";
                readonly operationId: "createPets";
                readonly tags: readonly ["pets"];
                readonly responses: {
                    readonly "201": {
                        readonly description: "Null response";
                    };
                    readonly default: {
                        readonly description: "unexpected error";
                        readonly schema: {
                            readonly $ref: "#/definitions/Error";
                        };
                    };
                };
            };
        };
        readonly "/pets/{petId}": {
            readonly get: {
                readonly summary: "Info for a specific pet";
                readonly operationId: "showPetById";
                readonly tags: readonly ["pets"];
                readonly parameters: readonly [{
                    readonly name: "petId";
                    readonly in: "path";
                    readonly required: true;
                    readonly description: "The id of the pet to retrieve";
                    readonly type: "string";
                }];
                readonly responses: {
                    readonly "200": {
                        readonly description: "Expected response to a valid request";
                        readonly schema: {
                            readonly $ref: "#/definitions/Pets";
                        };
                    };
                    readonly default: {
                        readonly description: "unexpected error";
                        readonly schema: {
                            readonly $ref: "#/definitions/Error";
                        };
                    };
                };
            };
        };
    };
    readonly definitions: {
        readonly Pet: {
            readonly type: "object";
            readonly required: readonly ["id", "name"];
            readonly properties: {
                readonly id: {
                    readonly type: "integer";
                    readonly format: "int64";
                };
                readonly name: {
                    readonly type: "string";
                };
                readonly tag: {
                    readonly type: "string";
                };
            };
        };
        readonly Pets: {
            readonly type: "array";
            readonly items: {
                readonly $ref: "#/definitions/Pet";
            };
        };
        readonly Error: {
            readonly type: "object";
            readonly required: readonly ["code", "message"];
            readonly properties: {
                readonly code: {
                    readonly type: "integer";
                    readonly format: "int32";
                };
                readonly message: {
                    readonly type: "string";
                };
            };
        };
    };
};
export default _default;
